"""Prompt Forge MCP server package."""

__version__ = "0.2.0"

def main():
    """Entry point for the MCP server."""
    from promptforge_mcp.server import main as _main
    _main()

__all__ = ["main", "__version__"]
